package com.sun.media.sound;

import java.nio.FloatBuffer;
import java.nio.ByteOrder;
import java.nio.DoubleBuffer;
import java.nio.ByteBuffer;
import javax.sound.sampled.AudioFormat;

public abstract class AudioFloatConverter
{
    private AudioFormat format;
    
    public AudioFloatConverter() {
    }
    
    public static AudioFloatConverter getConverter(AudioFormat format) {
        Object o = null;
        if (format.getFrameSize() == 0) {
            return null;
        }
        if (format.getFrameSize() != (format.getSampleSizeInBits() + 7) / 8 * format.getChannels()) {
            return null;
        }
        if (format.getEncoding().equals(AudioFormat.Encoding.PCM_SIGNED)) {
            if (format.isBigEndian()) {
                if (format.getSampleSizeInBits() <= 8) {
                    o = new AudioFloatConverter.AudioFloatConversion8S();
                }
                else if (format.getSampleSizeInBits() > 8 && format.getSampleSizeInBits() <= 16) {
                    o = new AudioFloatConverter.AudioFloatConversion16SB();
                }
                else if (format.getSampleSizeInBits() > 16 && format.getSampleSizeInBits() <= 24) {
                    o = new AudioFloatConverter.AudioFloatConversion24SB();
                }
                else if (format.getSampleSizeInBits() > 24 && format.getSampleSizeInBits() <= 32) {
                    o = new AudioFloatConverter.AudioFloatConversion32SB();
                }
                else if (format.getSampleSizeInBits() > 32) {
                    o = new AudioFloatConverter.AudioFloatConversion32xSB((format.getSampleSizeInBits() + 7) / 8 - 4);
                }
            }
            else if (format.getSampleSizeInBits() <= 8) {
                o = new AudioFloatConverter.AudioFloatConversion8S();
            }
            else if (format.getSampleSizeInBits() > 8 && format.getSampleSizeInBits() <= 16) {
                o = new AudioFloatConverter.AudioFloatConversion16SL();
            }
            else if (format.getSampleSizeInBits() > 16 && format.getSampleSizeInBits() <= 24) {
                o = new AudioFloatConverter.AudioFloatConversion24SL();
            }
            else if (format.getSampleSizeInBits() > 24 && format.getSampleSizeInBits() <= 32) {
                o = new AudioFloatConverter.AudioFloatConversion32SL();
            }
            else if (format.getSampleSizeInBits() > 32) {
                o = new AudioFloatConverter.AudioFloatConversion32xSL((format.getSampleSizeInBits() + 7) / 8 - 4);
            }
        }
        else if (format.getEncoding().equals(AudioFormat.Encoding.PCM_UNSIGNED)) {
            if (format.isBigEndian()) {
                if (format.getSampleSizeInBits() <= 8) {
                    o = new AudioFloatConverter.AudioFloatConversion8U();
                }
                else if (format.getSampleSizeInBits() > 8 && format.getSampleSizeInBits() <= 16) {
                    o = new AudioFloatConverter.AudioFloatConversion16UB();
                }
                else if (format.getSampleSizeInBits() > 16 && format.getSampleSizeInBits() <= 24) {
                    o = new AudioFloatConverter.AudioFloatConversion24UB();
                }
                else if (format.getSampleSizeInBits() > 24 && format.getSampleSizeInBits() <= 32) {
                    o = new AudioFloatConverter.AudioFloatConversion32UB();
                }
                else if (format.getSampleSizeInBits() > 32) {
                    o = new AudioFloatConverter.AudioFloatConversion32xUB((format.getSampleSizeInBits() + 7) / 8 - 4);
                }
            }
            else if (format.getSampleSizeInBits() <= 8) {
                o = new AudioFloatConverter.AudioFloatConversion8U();
            }
            else if (format.getSampleSizeInBits() > 8 && format.getSampleSizeInBits() <= 16) {
                o = new AudioFloatConverter.AudioFloatConversion16UL();
            }
            else if (format.getSampleSizeInBits() > 16 && format.getSampleSizeInBits() <= 24) {
                o = new AudioFloatConverter.AudioFloatConversion24UL();
            }
            else if (format.getSampleSizeInBits() > 24 && format.getSampleSizeInBits() <= 32) {
                o = new AudioFloatConverter.AudioFloatConversion32UL();
            }
            else if (format.getSampleSizeInBits() > 32) {
                o = new AudioFloatConverter.AudioFloatConversion32xUL((format.getSampleSizeInBits() + 7) / 8 - 4);
            }
        }
        else if (format.getEncoding().equals(AudioFormat.Encoding.PCM_FLOAT)) {
            if (format.getSampleSizeInBits() == 32) {
                if (format.isBigEndian()) {
                    o = new AudioFloatConverter.AudioFloatConversion32B();
                }
                else {
                    o = new AudioFloatConverter.AudioFloatConversion32L();
                }
            }
            else if (format.getSampleSizeInBits() == 64) {
                if (format.isBigEndian()) {
                    o = new AudioFloatConverter.AudioFloatConversion64B();
                }
                else {
                    o = new AudioFloatConverter.AudioFloatConversion64L();
                }
            }
        }
        if ((format.getEncoding().equals(AudioFormat.Encoding.PCM_SIGNED) || format.getEncoding().equals(AudioFormat.Encoding.PCM_UNSIGNED)) && format.getSampleSizeInBits() % 8 != 0) {
            o = new AudioFloatConverter.AudioFloatLSBFilter(o, format);
        }
        if (o != null) {
            o.format = format;
            return o;
        }
        return o;
    }
    
    public final AudioFormat getFormat() {
        return this.format;
    }
    
    public abstract float[] toFloatArray(byte[] p0, int p1, float[] p2, int p3, int p4);
    
    public final float[] toFloatArray(byte[] array, float[] array2, int n, int n2) {
        return this.toFloatArray(array, 0, array2, n, n2);
    }
    
    public final float[] toFloatArray(byte[] array, int n, float[] array2, int n2) {
        return this.toFloatArray(array, n, array2, 0, n2);
    }
    
    public final float[] toFloatArray(byte[] array, float[] array2, int n) {
        return this.toFloatArray(array, 0, array2, 0, n);
    }
    
    public final float[] toFloatArray(byte[] array, float[] array2) {
        return this.toFloatArray(array, 0, array2, 0, array2.length);
    }
    
    public abstract byte[] toByteArray(float[] p0, int p1, int p2, byte[] p3, int p4);
    
    public final byte[] toByteArray(float[] array, int n, byte[] array2, int n2) {
        return this.toByteArray(array, 0, n, array2, n2);
    }
    
    public final byte[] toByteArray(float[] array, int n, int n2, byte[] array2) {
        return this.toByteArray(array, n, n2, array2, 0);
    }
    
    public final byte[] toByteArray(float[] array, int n, byte[] array2) {
        return this.toByteArray(array, 0, n, array2, 0);
    }
    
    public final byte[] toByteArray(float[] array, byte[] array2) {
        return this.toByteArray(array, 0, array.length, array2, 0);
    }
    
    private static class AudioFloatLSBFilter extends AudioFloatConverter
    {
        private final AudioFloatConverter converter;
        private final int offset;
        private final int stepsize;
        private final byte mask;
        private byte[] mask_buffer;
        
        AudioFloatLSBFilter(AudioFloatConverter converter, AudioFormat audioFormat) {
            int sampleSizeInBits = audioFormat.getSampleSizeInBits();
            int bigEndian = audioFormat.isBigEndian();
            this.converter = converter;
            this.stepsize = (sampleSizeInBits + 7) / 8;
            this.offset = (bigEndian ? (this.stepsize - 1) : 0);
            int n = sampleSizeInBits % 8;
            if (n == 0) {
                this.mask = 0;
            }
            else if (n == 1) {
                this.mask = -128;
            }
            else if (n == 2) {
                this.mask = -64;
            }
            else if (n == 3) {
                this.mask = -32;
            }
            else if (n == 4) {
                this.mask = -16;
            }
            else if (n == 5) {
                this.mask = -8;
            }
            else if (n == 6) {
                this.mask = -4;
            }
            else if (n == 7) {
                this.mask = -2;
            }
            else {
                this.mask = -1;
            }
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            byte[] byteArray = this.converter.toByteArray(array, n, n2, array2, n3);
            for (int n4 = n2 * this.stepsize, i = n3 + this.offset; i < n4; i += this.stepsize) {
                array2[i] &= this.mask;
            }
            return byteArray;
        }
        
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            if (this.mask_buffer == null || this.mask_buffer.length < array.length) {
                this.mask_buffer = new byte[array.length];
            }
            System.arraycopy(array, 0, this.mask_buffer, 0, array.length);
            for (int n4 = n3 * this.stepsize, i = n + this.offset; i < n4; i += this.stepsize) {
                this.mask_buffer[i] &= this.mask;
            }
            return this.converter.toFloatArray(this.mask_buffer, n, array2, n2, n3);
        }
    }
    
    private static class AudioFloatConversion64L extends AudioFloatConverter
    {
        ByteBuffer bytebuffer;
        DoubleBuffer floatbuffer;
        double[] double_buff;
        
        private AudioFloatConversion64L() {
            this.bytebuffer = null;
            this.floatbuffer = null;
            this.double_buff = null;
        }
        
        @Override
        public float[] toFloatArray(byte[] src, int offset, float[] array, int i, int length) {
            int n = length * 8;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.LITTLE_ENDIAN);
                this.floatbuffer = this.bytebuffer.asDoubleBuffer();
            }
            this.bytebuffer.position(0);
            this.floatbuffer.position(0);
            this.bytebuffer.put(src, offset, n);
            if (this.double_buff == null || this.double_buff.length < length + i) {
                this.double_buff = new double[length + i];
            }
            this.floatbuffer.get(this.double_buff, i, length);
            int n2;
            for (n2 = i + length, ; i < n2; ++i) {
                array[i] = (float)this.double_buff[i];
            }
            return array;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int i, int length, byte[] dst, int offset) {
            int n = length * 8;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.LITTLE_ENDIAN);
                this.floatbuffer = this.bytebuffer.asDoubleBuffer();
            }
            this.floatbuffer.position(0);
            this.bytebuffer.position(0);
            if (this.double_buff == null || this.double_buff.length < i + length) {
                this.double_buff = new double[i + length];
            }
            int n2;
            for (n2 = i + length, ; i < n2; ++i) {
                this.double_buff[i] = (double)array[i];
            }
            this.floatbuffer.put(this.double_buff, i, length);
            this.bytebuffer.get(dst, offset, n);
            return dst;
        }
    }
    
    private static class AudioFloatConversion64B extends AudioFloatConverter
    {
        ByteBuffer bytebuffer;
        DoubleBuffer floatbuffer;
        double[] double_buff;
        
        private AudioFloatConversion64B() {
            this.bytebuffer = null;
            this.floatbuffer = null;
            this.double_buff = null;
        }
        
        @Override
        public float[] toFloatArray(byte[] src, int offset, float[] array, int i, int length) {
            int n = length * 8;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.BIG_ENDIAN);
                this.floatbuffer = this.bytebuffer.asDoubleBuffer();
            }
            this.bytebuffer.position(0);
            this.floatbuffer.position(0);
            this.bytebuffer.put(src, offset, n);
            if (this.double_buff == null || this.double_buff.length < length + i) {
                this.double_buff = new double[length + i];
            }
            this.floatbuffer.get(this.double_buff, i, length);
            int n2;
            for (n2 = i + length, ; i < n2; ++i) {
                array[i] = (float)this.double_buff[i];
            }
            return array;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int i, int length, byte[] dst, int offset) {
            int n = length * 8;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.BIG_ENDIAN);
                this.floatbuffer = this.bytebuffer.asDoubleBuffer();
            }
            this.floatbuffer.position(0);
            this.bytebuffer.position(0);
            if (this.double_buff == null || this.double_buff.length < i + length) {
                this.double_buff = new double[i + length];
            }
            int n2;
            for (n2 = i + length, ; i < n2; ++i) {
                this.double_buff[i] = (double)array[i];
            }
            this.floatbuffer.put(this.double_buff, i, length);
            this.bytebuffer.get(dst, offset, n);
            return dst;
        }
    }
    
    private static class AudioFloatConversion32L extends AudioFloatConverter
    {
        ByteBuffer bytebuffer;
        FloatBuffer floatbuffer;
        
        private AudioFloatConversion32L() {
            this.bytebuffer = null;
            this.floatbuffer = null;
        }
        
        @Override
        public float[] toFloatArray(byte[] src, int offset, float[] dst, int offset2, int length) {
            int n = length * 4;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.LITTLE_ENDIAN);
                this.floatbuffer = this.bytebuffer.asFloatBuffer();
            }
            this.bytebuffer.position(0);
            this.floatbuffer.position(0);
            this.bytebuffer.put(src, offset, n);
            this.floatbuffer.get(dst, offset2, length);
            return dst;
        }
        
        @Override
        public byte[] toByteArray(float[] src, int offset, int length, byte[] dst, int offset2) {
            int n = length * 4;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.LITTLE_ENDIAN);
                this.floatbuffer = this.bytebuffer.asFloatBuffer();
            }
            this.floatbuffer.position(0);
            this.bytebuffer.position(0);
            this.floatbuffer.put(src, offset, length);
            this.bytebuffer.get(dst, offset2, n);
            return dst;
        }
    }
    
    private static class AudioFloatConversion32B extends AudioFloatConverter
    {
        ByteBuffer bytebuffer;
        FloatBuffer floatbuffer;
        
        private AudioFloatConversion32B() {
            this.bytebuffer = null;
            this.floatbuffer = null;
        }
        
        @Override
        public float[] toFloatArray(byte[] src, int offset, float[] dst, int offset2, int length) {
            int n = length * 4;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.BIG_ENDIAN);
                this.floatbuffer = this.bytebuffer.asFloatBuffer();
            }
            this.bytebuffer.position(0);
            this.floatbuffer.position(0);
            this.bytebuffer.put(src, offset, n);
            this.floatbuffer.get(dst, offset2, length);
            return dst;
        }
        
        @Override
        public byte[] toByteArray(float[] src, int offset, int length, byte[] dst, int offset2) {
            int n = length * 4;
            if (this.bytebuffer == null || this.bytebuffer.capacity() < n) {
                this.bytebuffer = ByteBuffer.allocate(n).order(ByteOrder.BIG_ENDIAN);
                this.floatbuffer = this.bytebuffer.asFloatBuffer();
            }
            this.floatbuffer.position(0);
            this.bytebuffer.position(0);
            this.floatbuffer.put(src, offset, length);
            this.bytebuffer.get(dst, offset2, n);
            return dst;
        }
    }
    
    private static class AudioFloatConversion8S extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)array[n++] * 0.007874016f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                array2[n3++] = (byte)(int)(array[n++] * 127.0f);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion8U extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)((array[n++] & 0xFF) - 127) * 0.007874016f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                array2[n3++] = (byte)(int)(127.0f + array[n++] * 127.0f);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion16SL extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int i, int n2) {
            int n3;
            for (n3 = i + n2, ; i < n3; ++i) {
                array2[i] = (float)(short)((array[n++] & 0xFF) | array[n++] << 8) * 3.051851E-5f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int i, int n, byte[] array2, int n2) {
            int n3;
            int n4;
            for (n3 = i + n, ; i < n3; ++i) {
                n4 = (int)((double)array[i] * 32767.0);
                array2[n2++] = (byte)n4;
                array2[n2++] = (byte)(n4 >>> 8);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion16SB extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(short)(array[n++] << 8 | (array[n++] & 0xFF)) * 3.051851E-5f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)((double)array[n++] * 32767.0);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion16UL extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8) - 32767) * 3.051851E-5f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = 32767 + (int)((double)array[n++] * 32767.0);
                array2[n3++] = (byte)n4;
                array2[n3++] = (byte)(n4 >>> 8);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion16UB extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(((array[n++] & 0xFF) << 8 | (array[n++] & 0xFF)) - 32767) * 3.051851E-5f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = 32767 + (int)((double)array[n++] * 32767.0);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion24SL extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            int n4;
            for (int i = 0; i < n3; array2[n2++] = (float)n4 * 1.192093E-7f, ++i) {
                n4 = ((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF) << 16);
                if (n4 > 8388607) {
                    n4 -= 16777216;
                }
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            int n4;
            for (int i = 0; i < n2; array2[n3++] = (byte)n4, array2[n3++] = (byte)(n4 >>> 8), array2[n3++] = (byte)(n4 >>> 16), ++i) {
                n4 = (int)(array[n++] * 8388607.0f);
                if (n4 < 0) {
                    n4 += 16777216;
                }
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion24SB extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            int n4;
            for (int i = 0; i < n3; array2[n2++] = (float)n4 * 1.192093E-7f, ++i) {
                n4 = ((array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF));
                if (n4 > 8388607) {
                    n4 -= 16777216;
                }
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            int n4;
            for (int i = 0; i < n2; array2[n3++] = (byte)(n4 >>> 16), array2[n3++] = (byte)(n4 >>> 8), array2[n3++] = (byte)n4, ++i) {
                n4 = (int)(array[n++] * 8388607.0f);
                if (n4 < 0) {
                    n4 += 16777216;
                }
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion24UL extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF) << 16) - 8388607) * 1.192093E-7f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 8388607.0f) + 8388607;
                array2[n3++] = (byte)n4;
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)(n4 >>> 16);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion24UB extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(((array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF)) - 8388607) * 1.192093E-7f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 8388607.0f) + 8388607;
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32SL extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 24) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 2.1474836E9f);
                array2[n3++] = (byte)n4;
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 24);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32SB extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)((array[n++] & 0xFF) << 24 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF)) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 2.1474836E9f);
                array2[n3++] = (byte)(n4 >>> 24);
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32UL extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 24) - Integer.MAX_VALUE) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 2.1474836E9f) + Integer.MAX_VALUE;
                array2[n3++] = (byte)n4;
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 24);
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32UB extends AudioFloatConverter
    {
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                array2[n2++] = (float)(((array[n++] & 0xFF) << 24 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF)) - Integer.MAX_VALUE) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 2.1474836E9f) + Integer.MAX_VALUE;
                array2[n3++] = (byte)(n4 >>> 24);
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32xSL extends AudioFloatConverter
    {
        final int xbytes;
        
        AudioFloatConversion32xSL(int xbytes) {
            this.xbytes = xbytes;
        }
        
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                n += this.xbytes;
                array2[n2++] = (float)((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 24) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            int n4;
            for (int i = 0; i < n2; array2[n3++] = (byte)n4, array2[n3++] = (byte)(n4 >>> 8), array2[n3++] = (byte)(n4 >>> 16), array2[n3++] = (byte)(n4 >>> 24), ++i) {
                n4 = (int)(array[n++] * 2.1474836E9f);
                for (int j = 0; j < this.xbytes; ++j) {
                    array2[n3++] = 0;
                }
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32xSB extends AudioFloatConverter
    {
        final int xbytes;
        
        AudioFloatConversion32xSB(int xbytes) {
            this.xbytes = xbytes;
        }
        
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                int n4 = (array[n++] & 0xFF) << 24 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF);
                n += this.xbytes;
                array2[n2++] = (float)n4 * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)(array[n++] * 2.1474836E9f);
                array2[n3++] = (byte)(n4 >>> 24);
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
                for (int j = 0; j < this.xbytes; ++j) {
                    array2[n3++] = 0;
                }
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32xUL extends AudioFloatConverter
    {
        final int xbytes;
        
        AudioFloatConversion32xUL(int xbytes) {
            this.xbytes = xbytes;
        }
        
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                n += this.xbytes;
                array2[n2++] = (float)(((array[n++] & 0xFF) | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 24) - Integer.MAX_VALUE) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            int n4;
            for (int i = 0; i < n2; array2[n3++] = (byte)n4, array2[n3++] = (byte)(n4 >>> 8), array2[n3++] = (byte)(n4 >>> 16), array2[n3++] = (byte)(n4 >>> 24), ++i) {
                n4 = (int)(array[n++] * 2.1474836E9f) + Integer.MAX_VALUE;
                for (int j = 0; j < this.xbytes; ++j) {
                    array2[n3++] = 0;
                }
            }
            return array2;
        }
    }
    
    private static class AudioFloatConversion32xUB extends AudioFloatConverter
    {
        final int xbytes;
        
        AudioFloatConversion32xUB(int xbytes) {
            this.xbytes = xbytes;
        }
        
        @Override
        public float[] toFloatArray(byte[] array, int n, float[] array2, int n2, int n3) {
            for (int i = 0; i < n3; ++i) {
                int n4 = (array[n++] & 0xFF) << 24 | (array[n++] & 0xFF) << 16 | (array[n++] & 0xFF) << 8 | (array[n++] & 0xFF);
                n += this.xbytes;
                array2[n2++] = (float)(n4 - Integer.MAX_VALUE) * 4.656613E-10f;
            }
            return array2;
        }
        
        @Override
        public byte[] toByteArray(float[] array, int n, int n2, byte[] array2, int n3) {
            for (int i = 0; i < n2; ++i) {
                int n4 = (int)((double)array[n++] * 2.147483647E9) + Integer.MAX_VALUE;
                array2[n3++] = (byte)(n4 >>> 24);
                array2[n3++] = (byte)(n4 >>> 16);
                array2[n3++] = (byte)(n4 >>> 8);
                array2[n3++] = (byte)n4;
                for (int j = 0; j < this.xbytes; ++j) {
                    array2[n3++] = 0;
                }
            }
            return array2;
        }
    }
}
